// @require fashion/fashion-min.js

importPackage(com.sencha.util);

Fashion.Env.readFileRhino = function(file) {
    return FileUtil.readUnicodeFile(file) + '';
};

Fashion.Env.loadFileRhino = function(file, success, error) {
    try {
        success(Fashion.Env.readFile(file));
    } catch (err) {
        if(error) {
            error(err);
        }
    }
};

function fashionBuild(inputFile) {
    var builder = Fashion.mainbuilder || (Fashion.mainbuilder = new Fashion.Builder({
            libPaths: {
                compass: compassPath,
                blueprint: blueprintPath
            }
        })),
        syntax, sassFile;

    sassFile = builder.getSassFile(inputFile);
    sassFile.invalidate();
    sassFile.onReady(function(){
        syntax = sassFile.getExpandedAst();
    });

    return fashionConvert(syntax);
};

function fashionTokenize(sass) {
    return new Fashion.parse.Tokenizer().tokenize(sass);
}

function fashionParse(sass) {
    var parser = new Fashion.parse.Parser();
    return parser.parse(sass);
}

function fashionConvert(syntax) {
    var converter = new Fashion.Converter();
    Fashion.Runtime.defaultRuntime.converter = converter;
    return converter.convert(syntax);
}

function fashionRun(js) {
    return Fashion.Runtime.run(js);
}

function fashionGetCss(js) {
    return fashionRun(js).getText().join('');
}

function fashionCompile(syntax) {
    return fashionRun(fashionConvert(syntax));
}

function fashionCompileCss(sass) {
    return fashionCompile(fashionParse(fashionTokenize(sass))).getText();
}

function jsonEncode(obj) {
    return JSON.stringify(obj, ignoreLineNumber, 4);
}

function fashionFullCompile(path) {
    Fashion.Env.allowAsyncLoad = false;
    var converted = fashionBuild(path),
        runtime = Fashion.Runtime.defaultRuntime;

    runtime.docCache = runtime.converter.transpiler.docCache;
    runtime.stringCache = runtime.converter.transpiler.stringCache;

    var func = Fashion.Runtime.compile(converted);
    var css = func();
    return css.getText().join('');
}